@@ -1,12 +1,11 @@
 import sys
 import time
-import traceback
 from dataclasses import dataclass
+from functools import partial
 from typing import Iterable, List, Optional, Type
 
 import requests
 from atqo import ActorBase, SchedulerTask
-from atqo.utils import partial_cls
 from selenium.common.exceptions import WebDriverException
 from selenium.webdriver import Chrome
 from structlog import get_logger
@@ -98,7 +97,7 @@ class ConnectionSession(ActorBase):
         try:
             cached_resp = task.handler.load_cache(task.url)
         except Exception as e:
-            logger.warn("error during cache loading", e=e, e_type=type(e))
+            logger.warning("error during cache loading", e=e, e_type=type(e))
             cached_resp = None
         if cached_resp is not None:
             status = (
@@ -130,9 +129,9 @@ class ConnectionSession(ActorBase):
                     break
             except Exception as e:
                 content = e
-            logger.warning("Missed try", error=str(content), url=url, attempt=attempt)
+            self._log_miss("Failed Try", content, handler, attempt, "RETRY", url)
             if handler.is_session_broken(content):
-                raise BrokenSessionError(f"error: {content}")
+                raise BrokenSessionError(f"error: {content}".split("\n")[0])
             time.sleep(handler.get_retry_sleep_time())
         else:
             raise ConnectionError(f"request resulted in error with status {content}")
@@ -147,10 +146,7 @@ class ConnectionSession(ActorBase):
         self.session.start(self._proxy)
         self._num_queries = 0
 
-    def _get_uh_result(
-        self,
-        task: HandlingTask,
-    ) -> UrlHandlerResult:
+    def _get_uh_result(self, task: HandlingTask) -> UrlHandlerResult:
         try:
             out = self.get_parsed_response(task.url, task.handler)
             if task.handler.process_indefinitely:
@@ -160,26 +156,26 @@ class ConnectionSession(ActorBase):
         except Exception as e:
             out = _parse_exception(e)
             status = EXCEPTION_STATUSES.get(type(e), DEFAULT_EXCEPTION_STATUS)
-            _info = {**out, "proxy": self._proxy.host, "status": status}
-            logger.warning("Gave up", handler=task.handler_name, url=task.url, **_info)
+            _h = task.handler
+            self._log_miss("Gave Up", e, _h, _h.max_retries, status, task.url)
         return task.wrap_to_uhr(out, status)
 
     def _initiate_handler(self, handler: ANY_HANDLER_T):
-        for _ in range(handler.initiation_retries):
+        for att in range(handler.initiation_retries):
             try:
                 handler.start_session(self.session.driver)
                 self._initiated_handlers.add(handler.name)
                 return True
             except Exception as e:
-                logger.warning(
-                    "Failed initiating handler",
-                    handler_name=handler.name,
-                    **_parse_exception(e),
-                )
-                # TODO: might be overkill this
+                self._log_miss("Failed initiating handler", e, handler, att, "PRE", "")
                 self._restart()
                 time.sleep(handler.wait_on_initiation_fail)
 
+    def _log_miss(self, msg, content, handler: ANY_HANDLER_T, attempt, status, url):
+        out = _parse_exception(content)
+        _info = out | {"proxy": self._proxy.host, "status": status}
+        logger.warning(msg, handler=handler.name, url=url, attempt=attempt, **_info)
+
 
 class BrowserSession:
     def __init__(self, headless: bool, eager: bool, show_images: bool = False):
@@ -248,8 +244,7 @@ cap_to_kwarg = {
 }
 
 
-def get_actor_dict(handlers: Iterable[ANY_HANDLER_T]):
-    out = {}
+def get_actor_items(handlers: Iterable[ANY_HANDLER_T]):
     for handler in handlers:
         caps = handler.get_caps()
         full_kwargs = dict(proxy_cls=handler.proxy_cls)
@@ -261,11 +256,9 @@ def get_actor_dict(handlers: Iterable[ANY_HANDLER_T]):
             and handler.proxy.needs_auth
         ):
             raise RuntimeError("can't have auth (extension) in headless browser")
-        actor = partial_cls(ConnectionSession, **full_kwargs)
-        out[caps] = actor
-    return out
+        yield caps, partial(ConnectionSession, **full_kwargs)
 
 
 def _parse_exception(e):
-    tbl = [tb.strip().split("\n") for tb in traceback.format_tb(e.__traceback__)]
-    return {"e_type": type(e).__name__, "e": str(e), "tb": tbl}
+    # tbl = [tb.strip().split("\n") for tb in traceback.format_tb(e.__traceback__)]
+    return {"e_type": type(e).__name__, "e_msg": str(e).split("\n")[0]}  # , "tb": tbl}
